@@ -53,8 +53,6 @@ class Q_DECL_HIDDEN ContactViewer::Private
 public:
     Private(ContactViewer *parent)
         : mParent(parent)
-        , mBrowser(nullptr)
-        , mParentCollectionFetchJob(nullptr)
     {
         mStandardContactFormatter = new StandardContactFormatter;
         mContactFormatter = mStandardContactFormatter;
@@ -258,16 +256,17 @@ public:
         updateView(metaData.customFieldDescriptions(), addressBookName);
     }
 
-    ContactViewer *mParent = nullptr;
-    TextBrowser *mBrowser = nullptr;
+    QMetaObject::Connection mCollectionFetchJobConnection;
     KContacts::Addressee mCurrentContact;
     Item mCurrentItem;
+    ContactViewer *mParent = nullptr;
+    TextBrowser *mBrowser = nullptr;
     AbstractContactFormatter *mContactFormatter = nullptr;
     AbstractContactFormatter *mStandardContactFormatter = nullptr;
     CollectionFetchJob *mParentCollectionFetchJob = nullptr;
-    bool mShowQRCode;
     Prison::AbstractBarcode *mQRCode = nullptr;
     Prison::AbstractBarcode *mDataMatrix = nullptr;
+    bool mShowQRCode = true;
 };
 
 ContactViewer::ContactViewer(QWidget *parent)
@@ -341,13 +340,13 @@ void ContactViewer::itemChanged(const Item &contactItem)
 
     // stop any running fetch job
     if (d->mParentCollectionFetchJob) {
-        disconnect(d->mParentCollectionFetchJob, SIGNAL(result(KJob*)), this, SLOT(slotParentCollectionFetched(KJob*)));
+        disconnect(d->mCollectionFetchJobConnection);
         delete d->mParentCollectionFetchJob;
         d->mParentCollectionFetchJob = nullptr;
     }
 
     d->mParentCollectionFetchJob = new CollectionFetchJob(contactItem.parentCollection(), CollectionFetchJob::Base, this);
-    connect(d->mParentCollectionFetchJob, SIGNAL(result(KJob*)), SLOT(slotParentCollectionFetched(KJob*)));
+    d->mCollectionFetchJobConnection = connect(d->mParentCollectionFetchJob, &CollectionFetchJob::result, this, [this](KJob *job) {d->slotParentCollectionFetched(job);});
 }
 
 void ContactViewer::itemRemoved()
